/******************************************************************************/
// Code to generate estimates of governance weighting all data sources equally
// Section 5.2 and Figure 4 in paper
/******************************************************************************/

/******************************************************************************/
// Load and clean up dataset
/******************************************************************************/
// Load dataset
use "$filepath\data\resultsdata.dta"
// Drop some variables we don't need
drop *mean *sd *load *rep *alpha *beta *sigma
// Rename source variables for simplicity (stripping off "1" and "2" subscripts)
foreach src in $sourcelist{
	foreach per in $periodlist{
		foreach ind in $indlist{
			cap rename `src'`per'`ind'*1 `src'`per'`ind'*
			cap rename `src'`per'`ind'*2 `src'`per'`ind'*
		}
	}
}
// Rectangularize variable list to simplify subsequent code
// i.e. generate empty variables as needed so that all 35 data sources are listed in
// all time periods for all six aggregate indicators
foreach src in $sourcelist{
	foreach per in $periodlist{
		foreach ind in $indlist{
			qui cap su `src'`per'`ind'
			if _rc==111{
				qui gen `src'`per'`ind'=.
			}
		}
	}
}

/******************************************************************************/
// Generate average of standardized globally representative sources 
// for every indicator and period, rep`per'`ind'
// Will use this to anchor the units of all the non-representative sources
// Requires list of representative sources defined below in repsourcelist
/******************************************************************************/
global repsourcelist "eiu frh gcs gwp her hum ijt ipd prs rsf tpr vdm wmo"
foreach ind in $indlist{
	foreach per in $periodlist{
		foreach src in $repsourcelist{
			qui cap su `src'`per'`ind'
			if _rc==0{
				qui gen `src'`per'`ind'_reprsc=(`src'`per'`ind'-r(mean))/r(sd)
			}
		}
		// Generate the average of representative rescaled indicators, and re-standardize average
		qui egen rep`per'`ind'=rowmean(*`per'`ind'_reprsc)
		qui su rep`per'`ind'
		qui replace rep`per'`ind'=(rep`per'`ind'-r(mean))/r(sd)
	}
}

/******************************************************************************/
// Standardize every source variable `src'`per'`ind' to have the same mean and 
// standard deviation as anchor rep`per'`ind' in their common sample
/******************************************************************************/
foreach src in $sourcelist{
	foreach per in $periodlist{
		foreach ind in $indlist{
			qui cap su `src'`per'`ind'
			if _rc==0{
				qui su `src'`per'`ind' if `src'`per'`ind'~=. & rep`per'`ind'~=.
				qui gen `src'`per'`ind'_rsc=(`src'`per'`ind'-r(mean))/r(sd) if `src'`per'`ind'~=. & rep`per'`ind'~=.
				qui su rep`per'`ind' if `src'`per'`ind'~=. & rep`per'`ind'~=.
				qui replace `src'`per'`ind'_rsc=`src'`per'`ind'_rsc*r(sd)+r(mean) if `src'`per'`ind'~=. & rep`per'`ind'~=.
			}
		}
	}
}	

/******************************************************************************/
// Create the alternative aggregate indicator that just averages the standardized data
// Also create a dummy variable to indicate statistically significant differences
// from baseline estimates.  Because we don't have standard errors for the equally-weighted
// variant, assess significance only by asking whether value of equally-weighted index
// is inside the 90% confidence interval for the baseline estimate.
/******************************************************************************/
foreach per in $periodlist{
	foreach ind in $indlist{
		// Average and rescale
		qui egen `ind'e`per'_rsc=rowmean(*`per'`ind'_rsc)
		qui su `ind'e`per'_rsc
		qui replace `ind'e`per'_rsc=(`ind'e`per'_rsc-r(mean))/r(sd)
		// Dummy for significant differences from baseline
		qui gen `ind'e`per'_signif=0 if `ind'e`per'~=.
		qui replace `ind'e`per'_signif=1 if abs(`ind'e`per'-`ind'e`per'_rsc)>1.64*`ind's`per' & `ind'e`per'~=.
	}
}


/******************************************************************************/
// Calculate and store all pairwise correlations
/******************************************************************************/
// Vector to store counter
egen counter=seq()
// Initialize variables to store correlations
foreach ind in $indlist{
	qui gen `ind'_corr=.
	qui gen `ind'_sigdiff=.
}
// Loop over periods and indicators, calculating and storing pairwise correlations
// and share of observations with significant differences
scalar j=1
foreach per in $periodlist{
	foreach ind in $indlist{
		qui correlate `ind'e`per' `ind'e`per'_rsc
		qui replace `ind'_corr=r(rho) if counter==`=scalar(j)'
		qui su `ind'e`per'_signif
		qui replace `ind'_sigdiff=r(mean) if counter==`=scalar(j)'
		}
	scalar j=j+1
}

// Summarize correlations and share of significant (numbers cited in the text at end of Section 5.2)
// For all periods  
su *_corr
su *_sigdiff
// For most recent 2023
foreach per in 23{
	foreach ind in $indlist{
		correlate `ind'e`per' `ind'e`per'_rsc
		su `ind'e`per'_signif
	}
}

/******************************************************************************/
// Graph comparing baseline and alternative in globally-selected year $yr
/******************************************************************************/
foreach yr in 23{
	foreach ind in $indlist{
		twoway (scatter `ind'e`yr'_rsc `ind'e`yr') (lfit `ind'e`yr' `ind'e`yr'), ///
		xtitle("Baseline UCM") ytitle("Equally Weighted") title("`ind'") legend(off) name("`ind'fig", replace)
	}
}
graph combine vafig pvfig gefig rqfig rlfig ccfig, ///
	rows(3) cols(2) ysize(8) xsize(6) ///
	title("Comparison with Equally-Weighted Version") subtitle("(2023)")
graph save "$filepath\outputs\figure4.gph", replace