/******************************************************************************/
// Code to generate consistent estimates of global mean and standard deviation
// of governance, in Section 5.3 and Figure 5 in paper
/******************************************************************************/

/******************************************************************************/
// Define list of sources treated as representative for purposes of these calculations
/******************************************************************************/
// Global list of representative and non-representative data sources (from UCM code)
global repsrclist "eiu frh gcs gwp her hum ijt ipd prs rsf tpr vdm wmo"
global nonrepsrclist "adb afr asd bps bti ccr ebr eqi gcb gii hrm ifd irp lbo msi obi pia prc vab wbs wcy wjp"

// Option to pick as representative sources only a subset with complete time series coverage since 1996 
// to prevent entry and exit from the sample to affect trends in global mean -- gives very similar results to those described in text
//global repsrclist "eiu frh gcs hum prs vdm wmo"
//global nonrepsrclist "adb afr asd bps bti ccr ebr eqi gcb gii gwp her hrm ifd ipd irp lbo msi obi pia prc rsf tpr vab wbs wcy wjp"

/******************************************************************************/
// Load and clean up dataset
/******************************************************************************/
// Load dataset
use "$filepath\data\resultsdata.dta"
// Keep only estimated alpha and beta
keep cid *alpha *beta
// Keep only first row of dataset since parameter estimates are just repeated in every row
keep if cid==1
// Drop data from non-representative sources as they are not informative about global trends
foreach src in $nonrepsrclist{
	drop `src'*
	}
// Drop the non-representative parts of a few sources where they switch from non-representative to representative
drop *2alpha *2beta
// Simplify variable names
rename *1alpha *alpha
rename *1beta *beta

/******************************************************************************/
// Reshape to long format with years as rows, columns are source x indicator 
/******************************************************************************/
// Put source and year subscripts at end of variable name for easier reshaping
foreach per in $periodlist{
	foreach src in $repsrclist{
		foreach ind in $indlist{
			cap rename `src'`per'`ind'alpha `ind'alpha`src'`per'
			cap rename `src'`per'`ind'beta `ind'beta`src'`per'
			}
		}
	}
// Convert period subscripts into years that can be recognized by stata
foreach per in $periodlist{
	if `per'==96{
		rename *`per' *1996
		}
	if `per'==98{
		rename *`per' *1998
		}
	if `per'~=96 & `per'~=98{
		rename *`per' *20`per'
		}
}
// Make list of stubs of variable names for reshaping
// Note that list is rectangular, it includes variable names that don't exist in dataset, these get reshaped as missing for all years
global stublistalpha ""
global stublistbeta ""
foreach ind in $indlist{
	foreach src in $repsrclist{
		global stublistalpha "$stublistalpha `ind'alpha`src'"
		global stublistbeta "$stublistbeta `ind'beta`src'"
		}
	}
global stublist "$stublistalpha $stublistbeta"
// Reshape data so that years are in rows
qui reshape long $stublist, i(cid) j(year)

/******************************************************************************/
// Implement calculations
/******************************************************************************/
// Loop over all indicators and representative sources to calculate
// source-specific estimates of global mean and global standard deviation
foreach ind in $indlist{
	foreach src in $repsrclist{
		// Time series averages of the alphas and betas
		qui cap egen `ind'alpha`src'_av=mean(`ind'alpha`src')
		qui cap egen `ind'beta`src'_av=mean(`ind'beta`src')
		// Source-specific estimate of global mean (mu)
		qui cap gen `ind'mu`src'=(`ind'alpha`src'-`ind'alpha`src'_av)/`ind'beta`src'_av
		// Source-specific estimate of global standard deviation (gamma)
		qui cap gen `ind'gamma`src'=`ind'beta`src'/`ind'beta`src'_av
		}
	}
// Drop time series averages of alphas and betas since no longer needed
drop *_av

// Average across sources to get final estimates of global mean and standard deviation for each indicator
foreach ind in $indlist{
	qui egen `ind'muhat=rowmean(`ind'mu*)
	qui egen `ind'gammahat=rowmean(`ind'gamma*)
	}
	
//twoway line vamuhat pvmuhat gemuhat rqmuhat rlmuhat ccmuhat year, yscale(range(-1 1)) ylabel(-1 -.5 0 .5 1)
foreach ind in $indlist{
	twoway (line `ind'muhat year, lwidth(thick) lcolor(black)) (line `ind'gammahat year, lcolor(black) lwidth(thick) lpattern(dash)), ///
		xscale(range(1995 2025)) yscale(range(-2 2)) ylabel(-2 -1.5 -1 -.5 0 .5 1 1.5 2) yline(0, lpattern(solid) lwidth(thin)) yline(1, lpattern(solid) lwidth(thin)) ///
		title("`ind'") legend(off) name(`ind'fig, replace) 
}
graph combine vafig pvfig gefig rqfig rlfig ccfig, ///
	rows(3) cols(2) ysize(8) xsize(6) ///
	title("Global Mean and Std Deviation of Governance") subtitle("Mean -- Solid Line" "Standard Deviation -- Dashed Line")
graph save "$filepath\outputs\figure5.gph", replace

