/******************************************************************************/
// Master .do file for Kaufmann and Kraay (2023). "The Worldwide Governance Indicators:  Methodology and 2024 Update"
// This .do file reproduces analytical findings based on the data in the 2024 update of the Worldwide Governance Indicators (WGI)
// Note:  A separate reproducibility package for the 2024 WGI update itself is available at reproducibility.worldbank.org.
// Folder Structure:
//	Data:  		resultsdata.dta (from reproducibility package for 2024 WGI update)
//				sourcedata.dta (from reproducibility package for 2024 WGI update)
//				wgidataset_with_sourcedata.dta (from reproducibility package for 2024 WGI update)	
// 	Dofiles:	master.do (this file), which calls:
//					source_summary_20Sept2024.do
//					levels_changes_graphs_20Sept2024.do
//					signif_diffs_20Sept2024.do
//					pairwise_correlations_20Sept2024.do
//					alternate_weights_20Sept2024.do
//					global_averages_20Sept2024.do
//	Outputs:	table1a.xlsx, table1b.xlsx (ingredients of Table 1 in paper)
//				figure1.gph,...,figure5.gph (Figures 1-5 in paper)
//				reproducibility_package_logfile.smcl (log file with all outputs of this code, some of which are referred to in text -- indicated with comments)
// There are no dependencies between the individual .do files listed above and each can be run separately
//
// To run this package, copy the package into desired location and set 
// global filepath immediately below to point to this location.  Then run this file.
/******************************************************************************/

global filepath "your path"


/******************************************************************************/
// Preliminaries
/******************************************************************************/
clear
clear mata
clear matrix
set more off
set maxvar 100000
cap log close
log using "$filepath\outputs\reproducibility_package_logfile", replace
set varabbrev on

/******************************************************************************/
// Global lists of aggregate indicators, time periods, and data sources
/******************************************************************************/
global indlist "va pv ge rq rl cc"
global periodlist "96 98 00 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22 23" 
global sourcelist "adb afr asd bps bti ccr ebr eiu eqi frh gcb gcs gii gwp her hrm hum ifd ijt ipd irp lbo msi obi pia prc prs rsf tpr vab vdm wbs wcy wjp wmo"

/******************************************************************************/
// Generate information in Table 1 and Table 2  
/******************************************************************************/
clear
do "$filepath\dofiles\source_summary_20Sept2024.do"

/******************************************************************************/
// Generate Figure 1 and Figure 2 (levels and changes in aggregate indicators)
/******************************************************************************/
clear
do "$filepath\dofiles\levels_changes_graphs_20Sept2024.do"

/******************************************************************************/
// Calculate share of pairwise country comparisons and country over-time
// comparisons that are statistically significant
// Last paragraphs of Section 4.1 and 4.2 in paper, numbers discussed in text only
/******************************************************************************/
clear
do "$filepath\dofiles\signif_diffs_20Sept2024.do"

/******************************************************************************/
// Generate Figure 3 (pairwise correlations among data sources)
/******************************************************************************/
clear
do "$filepath\dofiles\pairwise_correlations_20Sept2024.do"

/******************************************************************************/
// Generate Figure 4 (alternative weighting scheme)
/******************************************************************************/
clear
do "$filepath\dofiles\alternate_weights_20Sept2024.do"

/******************************************************************************/
// Generate Figure 5 (global means and standard deviations of governance)
/******************************************************************************/
clear
do "$filepath\dofiles\global_averages_20Sept2024.do"