/******************************************************************************/
// Code to look at trends over time in correlation of data sources to consider
// hypothesis of "echo chamber"  Discussed in Section 5.1 of paper. 
// Code produces Figure 3
/******************************************************************************/

/******************************************************************************/
// Load and clean up dataset
/******************************************************************************/
use "$filepath\data\resultsdata.dta"
// Keep only data on sources
keep cid *va1 *va2 *pv1 *pv2 *ge1 *ge2 *rq1 *rq2 *rl1 *rl2 *cc1 *cc2
// Remove 1 and 2 subscripts from variable names
rename *1 *
rename *2 *
// Column vector containing values of periodlist
gen period=""
egen counter=seq()
scalar z=1
foreach per in $periodlist{
	replace period="`per'" if counter==`=scalar(z)'
	scalar z=z+1
}
drop counter
// Generate corresponding numerical year variable
gen zz="19" if period=="96" | period=="98"
replace zz="20" if period~="96" & period~="98" & period~=""
gen year=zz+period
destring year, replace
drop zz

/******************************************************************************/
// Define lists of expert assessments and surveys to compare correlations
// Use only data sources that have continuous coverage starting in 2005 or
// earlier to ensure that comparisons of average correlations over time make sense
/******************************************************************************/
// List of surveys  Commented-out option below allows selection of all household and firm surveys
global surveysourcelist "gcs wcy"  // Firm Surveys (Baseline)
//global surveysourcelist "afr gcb gcs gwp lbo prc vab wcy" // All surveys with long time series coverage

// ?ist of expert assessments.  Commented-out options below allow selection of commercial, government and NGO expert assessments
global expertsourcelist "eiu prs wmo ijt"						// Commercial (Baseline)
//global expertsourcelist "adb asd bti eiu frh gii her ifd ijt irp msi obi pia prs rsf tpr vdm wmo" // All
//global expertsourcelist "adb asd pia ifd tpr"					// Public Sector
//global expertsourcelist "bti frh gii her irp msi obi rsf vdm"	// NGO Sector

/******************************************************************************/
// Calculate pairwise correlations among all expert assessments and
// pairwise correlations of all expert assessments with all surveys
/******************************************************************************/
// Initialize variables to store the average correlations
foreach ind in $indlist{
	gen `ind'expertexpertcorr=.
	gen `ind'expertsurveycorr=.
}

// Loop of time periods and six aggregate indicators.  For each pair, loop over all
// expert assessments to compute pairwise correlations.  Then loop over all surveys
// and expert assessments to compute correlations between them.
foreach per in $periodlist{
	foreach ind in $indlist{
		// Pairwise correlation of expert assessments
		// Note that pairwise correlation between all expert assessments is recalculated in the
		// same set of countries covered by each of the surveys to ensure comparability with
		// correlations between expert assessments and surveys.
		// Note that loop redundantly calculates each pairwise correlation twice for simplicity of coding
		// This does not affect the average pairwise correlation.  Loop also drops correlations of surveys
		// with themselves by setting condition that correlation must be less than 0.99 to be considered
		scalar z=0
		scalar corrstor=0	
		foreach srci in $expertsourcelist{
			foreach srcj in $expertsourcelist{
				foreach srcsurv in $surveysourcelist{
					cap qui correlate `srci'`per'`ind' `srcj'`per'`ind' if `srcsurv'`per'`ind'~=.
					if _rc==0{
						if r(rho)<.99{
							scalar corrstor=corrstor+r(rho)
							scalar z=z+1
						}
					}
				}
			}
		}
		qui replace `ind'expertexpertcorr=corrstor/z if period=="`per'"
		// Correlation of expert assessments with surveys
		scalar z=0
		scalar corrstor=0
		foreach srcexp in $expertsourcelist{
			foreach srcsurv in $surveysourcelist{
			cap qui correlate `srcexp'`per'`ind' `srcsurv'`per'`ind'
			if _rc==0{
				scalar corrstor=corrstor+r(rho)
				scalar z=z+1
				}
			}
		}
		qui replace `ind'expertsurveycorr=corrstor/z if period=="`per'"
	}
}

/******************************************************************************/
// Graph results
/******************************************************************************/
foreach ind in $indlist{
	twoway (line `ind'expertexpertcorr year, lwidth(thick) lcolor(black)) ///
		(line `ind'expertsurveycorr year, lwidth(thick) lcolor(black) lpattern(dash)) if year>=2006, ///
		title("`ind'") ytitle("Correlation") yscale(range(0 1)) ylabel(0 0.25 0.50 0.75 1) legend(off) name("`ind'fig", replace)
}
graph combine vafig pvfig gefig rqfig rlfig ccfig, ///
	rows(3) cols(2) ysize(8) xsize(6) ///
	title("Pairwise Correlations of Data Sources") subtitle("Experts with Experts -- Solid Line" "Experts with Surveys -- Dashed Line")
	
graph save "$filepath\outputs\figure3.gph", replace