/******************************************************************************/
// Code to calculate significant differences (across countries, and over time)
/******************************************************************************/

/******************************************************************************/
// Load dataset
/******************************************************************************/
use "$filepath\data\resultsdata.dta"

/******************************************************************************/
// Define a mata function that efficiently calculates significant pairwise 
// differences across countries for a given indicator and year
// Takes as input a matrix (created in Stata) containing the two columns of
// governance compare, and the two columns of standard errors.
// Function returns 1x1 matrix "sigshare" containing share of pairwise comparisons
// that are significantly different
/******************************************************************************/
mata: 
  //mata drop sigdiff() 
  function sigdiff() {
    // Retrieve matrix passed from Stata and break apart into four columns with estimates and standard deviations
    x=st_matrix("x")
    est1=x[.,1]
    est2=x[.,2]
    sd1=x[.,3]
    sd2=x[.,4]
    // Vectors with lower and upper bounds of confidence intervals in both periods
    lower1=est1-1.64*sd1
    upper1=est1+1.64*sd1
    lower2=est2-1.64*sd2
    upper2=est2+1.64*sd2
    // Two matrices with 0/1 indicating whether upper1<lower2 and lower1>upper2
    comp1=(upper1#J(1,rows(est1),1)):<(J(rows(est1),1,1)#(lower2'))
    comp2=(lower1#J(1,rows(est1),1)):>(J(rows(est1),1,1)#(upper2'))
    comp=comp1+comp2
    // Share of significant differences.  
    // sum(comp) gives 2 times number of significant diffs
    // express as share of N(N-1) possible pairwise comparisons
    sigshare=sum(comp)/(rows(est1)*(rows(est1)-1))
    // Pass result back to Stata
    st_matrix("sigshare",sigshare)
  }
end

/******************************************************************************/
// Loop over indicators and years to calculate the share of significant 
// pairwise differences across countries within each indicator-year pair
/******************************************************************************/
foreach ind in $indlist {
	foreach yr in $periodlist {
		// Make matrix est1~est2~sd1~sd2 to pass to mata, containing only rows for which both indicators are available
		mkmat `ind'e`yr' `ind'e`yr' `ind's`yr' `ind's`yr' if `ind'e`yr'~=. & `ind'e`yr'~=., matrix(x)
		// Call mata function
		mata: sigdiff()
		// Retrieve 1x1 matrix passed by mata containing share of significant differences and display result
   		svmat sigshare
		gen `ind'`yr'_sigshare=sigshare
		drop sigshare
	}
}

/******************************************************************************/
// Summary statistics on share of significant differences 
// Discussed in last paragraph of Section 4.1
/******************************************************************************/
// Overall average rate of significant differences (unweighted average across all indicators and all years)
egen xx=rowmean(*_sigshare)
su xx
drop xx
// Average for each of the six indicators (averaging across all years)
foreach ind in $indlist{
	egen av_`ind'=rowmean(`ind'*_sigshare)
	su av_`ind'
}
// Average by year across all six indicators 
foreach yr in $periodlist{
	egen av_`yr'=rowmean(*`yr'_sigshare)
	su av_`yr'
}

/******************************************************************************/
// Significant changes over time 
// Use wgidataset_with_sourcedata.dta because its "long" format is more convenient
/******************************************************************************/
clear
use "$filepath\data\wgidataset_with_sourcedata.dta"
// xtset the data to be able to use time series lag operators
egen xid=group(code indicator)
tsset xid year

/******************************************************************************/
// Calculate share of significant differences within countries over different time horizons
/******************************************************************************/
// Set width of confidence interval 
scalar ciwidth=1.64		// 90 percent confidence interval
scalar ciwidth=1		// 68 percent confidence interval
// Loop over four different horizons 1, 5, 10 and 27 (maximum) years
foreach len in 1 5 10 27{
	gen diff_`len'=estimate-L`len'.estimate
	gen sigdiff_`len'=0 if diff_`len'~=.
	replace sigdiff_`len'=1 if diff_`len'~=. & (estimate+`=scalar(ciwidth)'*stddev<L`len'.estimate-`=scalar(ciwidth)'*L`len'.stddev | ///
											    estimate-`=scalar(ciwidth)'*stddev>L`len'.estimate+`=scalar(ciwidth)'*L`len'.stddev)
	}

/******************************************************************************/
// Summary statistics on share of significant changes
// Discussed in text in last paragraph of Section 4.2
/******************************************************************************/
// All annual changes (all indicators)
su sigdiff_1
// All five year changes (all indicators)
su sigdiff_5
// All ten year changes (all indicators)
su sigdiff_10
// Longest possible 27-year change (all indicators)
su sigdiff_27 
// 27-year change by indicators
foreach ind in $indlist{
	su sigdiff_27 if indicator=="`ind'"
} 
